# [QuGradLab](README.md) Change Log

## Release 0.1.1

Fixed typo in README.

## Release 0.1.0

This is the initial release. Future changes to this release will be documented above. Note that all versions ``0.*`` may have unstable APIs.